package App::MSOfficeUtils;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-08-21'; # DATE
our $DIST = 'App-MSOfficeUtils'; # DIST
our $VERSION = '0.000'; # VERSION

1;
# ABSTRACT: Utilities related to Microsoft Office

__END__

=pod

=encoding UTF-8

=head1 NAME

App::MSOfficeUtils - Utilities related to Microsoft Office

=head1 VERSION

This document describes version 0.000 of App::MSOfficeUtils (from Perl distribution App-MSOfficeUtils), released on 2020-08-21.

=head1 DESCRIPTION

B<CURRENTLY PLACEHOLDER ONLY>.

This distributions provides the following command-line utilities:

=over

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-MSOfficeUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-MSOfficeUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-MSOfficeUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::LibreOfficeUtils>

L<App::OfficeUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
